@@ -26,6 +26,7 @@
 #include <freerdp/input.h>
 #include <guacamole/client.h>
 #include <guacamole/mem.h>
+#include <guacamole/rwlock.h>
 
 #include <stdlib.h>
 
@@ -718,7 +719,7 @@ BOOL guac_rdp_keyboard_set_indicators(rdpContext* context, UINT16 flags) {
     guac_client* client = ((rdp_freerdp_context*) context)->client;
     guac_rdp_client* rdp_client = (guac_rdp_client*) client->data;
 
-    pthread_rwlock_rdlock(&(rdp_client->lock));
+    guac_rwlock_acquire_read_lock(&(rdp_client->lock));
 
     /* Skip if keyboard not yet ready */
     guac_rdp_keyboard* keyboard = rdp_client->keyboard;
@@ -730,7 +731,7 @@ BOOL guac_rdp_keyboard_set_indicators(rdpContext* context, UINT16 flags) {
     keyboard->lock_flags = flags;
 
 complete:
-    pthread_rwlock_unlock(&(rdp_client->lock));
+    guac_rwlock_release_lock(&(rdp_client->lock));
     return TRUE;
 
 }
