@@ -192,6 +192,12 @@ typedef struct guac_rdp_settings {
      */
     int resolution;
 
+    /**
+     * Whether all graphical updates for this connection should use lossless
+     * compression only.
+     */
+    int lossless;
+
     /**
      * Whether audio is enabled.
      */
@@ -317,6 +323,19 @@ typedef struct guac_rdp_settings {
      */
     int disable_paste;
 
+    /**
+     * Whether line endings within the clipboard should be automatically
+     * normalized to Unix-style newline characters.
+     */
+    int normalize_clipboard;
+
+    /**
+     * Whether Unix-style newline characters within the clipboard should be
+     * automatically translated to CRLF sequences before transmission to the
+     * RDP server.
+     */
+    int clipboard_crlf;
+
     /**
      * Whether the desktop wallpaper should be visible. If unset, the desktop
      * wallpaper will be hidden, reducing the amount of bandwidth required.
@@ -505,6 +524,14 @@ typedef struct guac_rdp_settings {
      */
     int recording_exclude_mouse;
 
+    /**
+     * Non-zero if changes to touch state should NOT be included in the session
+     * recording, zero otherwise. Touch state is included by default, as it may
+     * be necessary for touch interactions to be rendered in any resulting
+     * video.
+     */
+    int recording_exclude_touch;
+
     /**
      * Non-zero if keys pressed and released should be included in the session
      * recording, zero otherwise. Key events are NOT included by default within
@@ -525,6 +552,11 @@ typedef struct guac_rdp_settings {
      */
     int enable_audio_input;
 
+    /**
+     * Whether multi-touch support is enabled.
+     */
+    int enable_touch;
+
     /**
      * The hostname of the remote desktop gateway that should be used as an
      * intermediary for the remote desktop connection. If no gateway should
@@ -583,6 +615,11 @@ typedef struct guac_rdp_settings {
      */
     char* wol_broadcast_addr;
     
+    /**
+     * The UDP port to use when sending the magic WoL packet.
+     */
+    unsigned short wol_udp_port;
+    
     /**
      * The amount of time to wait after sending the magic WoL packet before
      * continuing the connection.
