@@ -24,6 +24,7 @@
 #include "settings.h"
 #include "terminal/terminal.h"
 
+#include <guacamole/mem.h>
 #include <guacamole/user.h>
 #include <guacamole/wol-constants.h>
 
@@ -278,7 +279,7 @@ enum TELNET_ARGS_IDX {
 /**
  * Compiles the given regular expression, returning NULL if compilation fails
  * or of the given regular expression is NULL. The returned regex_t must be
- * freed with regfree() AND free(), or with guac_telnet_regex_free().
+ * freed with regfree() AND guac_mem_free(), or with guac_telnet_regex_free().
  *
  * @param user
  *     The user who provided the setting associated with the given regex
@@ -298,7 +299,7 @@ static regex_t* guac_telnet_compile_regex(guac_user* user, char* pattern) {
         return NULL;
 
     int compile_result;
-    regex_t* regex = malloc(sizeof(regex_t));
+    regex_t* regex = guac_mem_alloc(sizeof(regex_t));
 
     /* Compile regular expression */
     compile_result = regcomp(regex, pattern,
@@ -308,7 +309,7 @@ static regex_t* guac_telnet_compile_regex(guac_user* user, char* pattern) {
     if (compile_result != 0) {
         guac_user_log(user, GUAC_LOG_ERROR, "Regular expression '%s' "
                 "could not be compiled.", pattern);
-        free(regex);
+        guac_mem_free(regex);
         return NULL;
     }
 
@@ -318,7 +319,7 @@ static regex_t* guac_telnet_compile_regex(guac_user* user, char* pattern) {
 void guac_telnet_regex_free(regex_t** regex) {
     if (*regex != NULL) {
         regfree(*regex);
-        free(*regex);
+        guac_mem_free(*regex);
         *regex = NULL;
     }
 }
@@ -334,7 +335,7 @@ guac_telnet_settings* guac_telnet_parse_args(guac_user* user,
         return NULL;
     }
 
-    guac_telnet_settings* settings = calloc(1, sizeof(guac_telnet_settings));
+    guac_telnet_settings* settings = guac_mem_zalloc(sizeof(guac_telnet_settings));
 
     /* Read parameters */
     settings->hostname =
@@ -538,12 +539,12 @@ guac_telnet_settings* guac_telnet_parse_args(guac_user* user,
 void guac_telnet_settings_free(guac_telnet_settings* settings) {
 
     /* Free network connection information */
-    free(settings->hostname);
-    free(settings->port);
+    guac_mem_free(settings->hostname);
+    guac_mem_free(settings->port);
 
     /* Free credentials */
-    free(settings->username);
-    free(settings->password);
+    guac_mem_free(settings->username);
+    guac_mem_free(settings->password);
 
     /* Free various regexes */
     guac_telnet_regex_free(&settings->username_regex);
@@ -552,26 +553,26 @@ void guac_telnet_settings_free(guac_telnet_settings* settings) {
     guac_telnet_regex_free(&settings->login_failure_regex);
 
     /* Free display preferences */
-    free(settings->font_name);
-    free(settings->color_scheme);
+    guac_mem_free(settings->font_name);
+    guac_mem_free(settings->color_scheme);
 
     /* Free typescript settings */
-    free(settings->typescript_name);
-    free(settings->typescript_path);
+    guac_mem_free(settings->typescript_name);
+    guac_mem_free(settings->typescript_path);
 
     /* Free screen recording settings */
-    free(settings->recording_name);
-    free(settings->recording_path);
+    guac_mem_free(settings->recording_name);
+    guac_mem_free(settings->recording_path);
 
     /* Free terminal emulator type. */
-    free(settings->terminal_type);
+    guac_mem_free(settings->terminal_type);
     
     /* Free WoL settings. */
-    free(settings->wol_mac_addr);
-    free(settings->wol_broadcast_addr);
+    guac_mem_free(settings->wol_mac_addr);
+    guac_mem_free(settings->wol_broadcast_addr);
 
     /* Free overall structure */
-    free(settings);
+    guac_mem_free(settings);
 
 }
 
