@@ -27,18 +27,6 @@
 #include <sys/types.h>
 #include <regex.h>
 #include <stdbool.h>
-
-/**
- * The name of the font to use for the terminal if no name is specified.
- */
-#define GUAC_TELNET_DEFAULT_FONT_NAME "monospace" 
-
-/**
- * The size of the font to use for the terminal if no font size is specified,
- * in points.
- */
-#define GUAC_TELNET_DEFAULT_FONT_SIZE 12
-
 /**
  * The port to connect to when initiating any telnet connection, if no other
  * port is specified.
@@ -67,11 +55,6 @@
  */
 #define GUAC_TELNET_DEFAULT_PASSWORD_REGEX "[Pp]assword:"
 
-/**
- * The default maximum scrollback size in rows.
- */
-#define GUAC_TELNET_DEFAULT_MAX_SCROLLBACK 1000
-
 /**
  * Settings for the telnet connection. The values for this structure are parsed
  * from the arguments given during the Guacamole protocol handshake using the
